const injuries = require('express').Router();
const pool = require('../../database.js');

var admin = require('firebase-admin');
/*admin.initializeApp({
  credential: admin.credential.applicationDefault(),
  databaseURL: 'https://bachelorprosjekt-spillerstatus.firebaseio.com'
});*/

// POST injuries - Register a new injury
injuries.post('/', async (request, response) => {
  let conn;
  try {
    response.set("Content-Type", "application/json");
    conn = await pool.getConnection();

    // Get the current date in MySQL date format
    const today = new Date();
    const day = (today.getDate() < 10) ? '0'+ today.getDate() : today.getDate();
    const month = (today.getMonth() < 9) ? '0' + (today.getMonth()+1) : (today.getMonth()+1);
    const date_reg = today.getFullYear() + '-' + month + '-' + day;

    // Store the injury in the database and update the athlete's status to unexamined by health professional
    const data = [
      request.body.athleteId,
      request.body.title
    ];
    const sqla = `INSERT INTO Injury (athlete_id, title, date_registered) VALUES (
                  ?, ?, CURDATE())`;
    const row = await conn.query(sqla, data);
    const sqlb = `UPDATE AthleteStatus SET status='4', summary='Ny skade registrert' WHERE athlete_id=?`;
    await conn.query(sqlb, [ request.body.athleteId ]);

    let newInjuryMessage = request.body.title + ': ' + request.body.message + '.';
    if(request.body.contact == "on"){
      newInjuryMessage = newInjuryMessage.concat(' - Kontakt meg for timebestilling.');
    }

    response.json({"status":"OK", "injury": {"id": row.insertId, "date_reg": date_reg, "title": request.body.title}, "message": newInjuryMessage});

  } catch (err) {
    response.json({"status":"ERR","error":err});
  } finally {
    if (conn) return conn.end();
  }
});

// GET injuries - Get all injuries for an athlete by athleteID
injuries.get('/:id', async (request, response) => {
  let conn;
  try {
    response.set("Content-Type", "application/json");
    conn = await pool.getConnection();

    // Get archived and non-archived injuries separately
    const data = [ request.params.id ];
    const sql1 = `SELECT injury_id AS id, title, description, DATE_FORMAT(date_registered,'%e/%c-%y') AS date_reg,
      DATE_FORMAT(date_injury,'%e/%c-%y') AS date_inj, DATE_FORMAT(date_recovered,'%e/%c-%y') AS date_rec, archived FROM Injury
      WHERE athlete_id=? AND archived=0 ORDER BY date_reg DESC, id DESC`;
    const sql2 = `SELECT injury_id AS id, title, description, DATE_FORMAT(date_registered,'%e/%c-%y') AS date_reg,
      DATE_FORMAT(date_injury,'%e/%c-%y') AS date_inj, DATE_FORMAT(date_recovered,'%e/%c-%y') AS date_rec, archived FROM Injury
      WHERE athlete_id=? AND archived=1 ORDER BY date_reg DESC, id DESC`;
    const row1 = await conn.query(sql1, data);
    const row2 = await conn.query(sql2, data);
    delete row1.meta; // row1 contains an array of injuries, but we don't want to send the metadata
    delete row2.meta;

    response.json({"status":"OK","injuries_active":row1,"injuries_archived":row2});

  } catch (err) {
     response.json({"status":"ERR","error":err});
  } finally {
    if (conn) return conn.end();
  }
});

// PUT injuries('/: - Update an injury (for athletes) by injuryID
injuries.put('/:id/:action', async (request, response) => {
  let conn;
  try {
    conn = await pool.getConnection();
    response.set("Content-Type", "application/json");

    switch(request.params.action) {
      case "editTitle":
        var data = [ request.body.title, request.params.id ];
        var sql = `UPDATE Injury SET title=? WHERE injury_id=?`;
        await conn.query(sql, data);
        break;
      case "archive":
        var data = [ request.params.id ];
        var sql = `UPDATE Injury SET archived=1 WHERE injury_id=?`;
        await conn.query(sql, data);
        break;
      case "unarchive":
        var data = [ request.params.id ];
        var sql = `UPDATE Injury SET archived=0 WHERE injury_id=?`;
        await conn.query(sql, data);
        break;
      default:
    }
    response.json({"status":"OK"});

  } catch (err) {
    response.json({"status":"ERR","error":err});
  } finally {
    if (conn) return conn.end();
  }
});

module.exports = injuries;
