import { html } from 'lit-element';
import { PageViewElement } from './page-view-element.js';
import { SharedStyles } from './shared-styles.js';

import { connect } from 'pwa-helpers/connect-mixin.js';
import { store } from '../store.js';
import { fixDrawerPosition } from '../helpers/position-fix.js';
import './log-in.js';
import './user-profile.js';
import './team-rep-home.js';
import './health-prof-home.js';

/*
  This component loads the content for the app's home page (whereas MyApp loads the UI).
  Content is loaded dynamically depending on login status and user type.
*/
class FrontPage extends connect(store)(PageViewElement) {
  static get properties() {
    return {
      _loggedIn: { type: Boolean },
      _userID: { type: Number },
      _userType: { type: Number },
      _drawerOpened: { type: Boolean }
    };
  }

  static get styles() {
    return [
      SharedStyles
    ];
  }

  stateChanged(state) {
    this._loggedIn = state.session.loggedIn;
    this._userID = state.session.userID;
    this._userType = state.session.userType;
    this._drawerOpened = state.app.drawerOpened;
  }

  render() {
    fixDrawerPosition(this);
    return html`
      <div id="page" class="page-wide-content-container">
        ${this._loggedIn ?
          html`${this._userType === 1 ? html`
            <user-profile .userID="${this._userID}"></user-profile>
          ` : html`
            ${this._userType === 2 ? html`
              <team-rep-home .userID="${this._userID}"></team-rep-home>
            ` : html`
              ${this._userType === 3 ? html`
                <health-prof-home .userID="${this._userID}"></health-prof-home>
              ` : html`
                ${this._userType === 4 ? html`
                  Administrator
                ` : html``}`}`}`}
        ` : html`<log-in></log-in>`}
      </div>
    `;
  }
}

window.customElements.define('front-page', FrontPage);
