import { html, css, LitElement } from 'lit-element';
import { PageViewElement } from './page-view-element.js';
import { connect } from 'pwa-helpers/connect-mixin.js';
import { store } from '../store.js';
import { SharedStyles } from './shared-styles.js';
import { formDataToJson } from '../helpers/form-data.js';
import { appurl } from '../helpers/url.js';
import { fetchResource } from '../actions/server-fetch.js';
import { addMessage } from '../actions/inbox.js';

class InboxContent extends connect(store)(LitElement) {
  static get properties(){
    return {
        user: { type: Number },
        currentAthleteId: { type: String },
        currentInjuryId: { type: String },
        messages: { type: Object },
    };
  }

  static get styles() {
    return [
      SharedStyles,
      css`
      /* This was .inbox*/
        :host {
          display: flex;
          flex-direction: column;
          justify-content: space-between;
        }
        .messages {
          max-height: calc(100vh - 310px);
          max-height: -moz-calc(100vh - 310px);
          max-height: -webkit-calc(100vh - 310px);
          min-height: calc(100vh - 310px);
          min-height: -moz-calc(100vh - 310px);
          min-height: -webkit-calc(100vh - 310px);
          overflow-y: scroll;
          transform: rotate(180deg);
          direction: rtl;
          text-align: left;
        }
        .messages-inside {
          overflow:hidden;
          transform: rotate(180deg);
          direction: ltr;
        }
        .message-container {
          padding: 5px 0 5px 0;;
          display: flex;
          flex-direction: column;
          border-bottom: 1px solid #eee;
        }
        .message-container:last-of-type {
          border-bottom: 0px;
        }
        .message-from {
          display: flex;
          flex-direction: row;
          justify-content: space-between;
        }
        .message-content {
          padding: 3px 0 0 5px;
        }

        .input-app-button {
          padding: 5px 0;
          width: 70px;
          margin: 0;
        }
        .inbox-new-message {
          margin-top: 10px;
        }
        textarea {
          border: 1px solid #eee;
        }
        .date {
          color: var(--secondary-color);
          font-weight: none;
        }
        .from {
          font-weight: bold;
        }

      `
    ];
  }

  render() {
    return html`
            <div class="messages" id="messages-container">
              <div class="messages-inside">
              ${Object.keys(this.messages).map((mKey)=> {
                if(mKey !== '0'){
                  return html`
                    <div class="message-container" id=${this.messages[mKey].id}>
                      <div class="message-from"><div class="from">${this.messages[mKey].from}</div><div class="date">${this.messages[mKey].date}</div></div>
                      <div class="message-content">${this.messages[mKey].content}</div>
                    <div>
                  `;
                }
              })}
              </div>
            </div>
            <form class="inbox-new-message" id="new-message" @submit="${this._submitForm}">
              <input type="hidden" name="from" value="${this.user}">
              <input type="hidden" name="to" value="${this.currentAthleteId}">
              <input type="hidden" name="injury" value="${this.currentInjuryId}">
              <textarea id="textbox" form="new-message" name="message" rows="3" cols="30"></textarea>
              <input type="submit" class="input-app-button" value="Send">
            </form>
    `
  }

  async _submitForm(event) {
    const formElement = this.shadowRoot.getElementById("new-message");
    const jsonFormData = formDataToJson(formElement);
    const url = appurl + "/api/inbox";
    const fetchOptions = {
      method: "POST",
      headers: { "Content-Type": "application/json" },
      body: jsonFormData
    };
    store.dispatch(fetchResource(url, fetchOptions)).then(() => {
      const data = store.getState().resources.data;

    if(data.status == 'OK'){
      //store.dispatch(addMessage(data.message));
        if(!firebase.messaging.isSupported()){
          store.dispatch(addMessage(data.message));
        }
        this.shadowRoot.getElementById("textbox").value="";

    } else {
      console.log('error');
    }

    })
    event.preventDefault();
  }

}

window.customElements.define('inbox-content', InboxContent);
