import { appurl } from './url.js';
const messaging = firebase.messaging();

/*
  Displays prompt for permission to show notifications.
  If accepted, stores the Instance ID token in the database
  for the passed in user.
  Called immediately after a successful login.
*/

export function loginRequestPermission(userID) {
  // Request user permission to receive notifications
  messaging.requestPermission().then(() => {
    return messaging.getToken();
  }).then(token => {
    if(token){
      // Store token in database
      const body = { userID: userID, token: token };
      const url = appurl + "/api/token";
      const fetchOptions = {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify(body)
      };
      fetch(url, fetchOptions);
    } else {
      console.log('No Instance ID token available');
    }
  }).catch(function(err){
    console.log('No permission. ', err);
  });
}
